summary.credibleshiftset: Summary of credible set of shift configurations from a BAMM analysis.
Description
Prints summary attributes of the BAMM credible set of shift configurations.
Usage
## S3 method for class 'credibleshiftset':
summary(object, ...)
## S3 method for class 'credibleshiftset':
print(x, ...)
Arguments
object,x
an object of class credibleshiftset.
...
additional arguments (unused).
Value
summary.credibleshiftset returns (invisibly) a dataframe with a number of rows equal to the number of shift configurations in the credible set and four columns:
rankThe ranked index of each shift configuration (ranked by posterior probability)
probabilitythe posterior probability of each shift configuration
cumulativethe cumulative probability of each shift configuration
N_shiftsthe number of rate shifts in each shift configuration (can be zero).
Details
Prints to console summary attributes of the XX% credible set of shift configurations sampled using BAMM. Attributes printed include: the number of distinct configurations in the XX% credible set and the posterior probability, cumulative probability, and number of rate shifts in the 9 most-probable shift configurations.